@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2016-01-15'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2016-01-21'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010001;
 use strict;
@@ -577,11 +577,13 @@ _
                         push @l, '        print ', dmp($res->[2]), '; exit 0;', "\n";
                     } elsif ($specmeta->{common_opt} eq 'version') {
                         no strict 'refs';
-                        push @l, '        print "', $script_name , ' version ',
-                            (defined($args{script_version}) ? $args{script_version} :
-                             $mod && ${"$mod\::VERSION"} ? ${"$mod\::VERSION"} : '?'),
-                            ($mod && ${"$mod\::DATE"} ? " (".${"$mod\::DATE"}.")" : ''),
-                            '\n";', "\n";
+                        push @l, "        no warnings 'once';\n";
+                        push @l, "        require $mod;\n" if $mod;
+                        push @l, '        print "', $script_name , ' version ", ',
+                            (defined($args{script_version}) ? "\"$args{script_version}\"" :
+                             "(\$$mod\::VERSION // '?')"),
+                             ", (\$$mod\::DATE ? \" (\$$mod\::DATE)\" : '')",
+                             ', "\\n";', "\n";
                         push @l, '        print "  Generated by ', __PACKAGE__ , ' version ',
                             (${__PACKAGE__."::VERSION"} // 'dev'),
                             (${__PACKAGE__."::DATE"} ? " (".${__PACKAGE__."::DATE"}.")" : ""),
@@ -812,7 +814,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.33 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-01-15.
+This document describes version 0.34 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-01-21.
 
 =head1 SYNOPSIS
 
@@ -1059,13 +1061,6 @@ Use L<App::GenPericmdCompleterScript> to generate a separate completion script.
 If you use L<Dist::Zilla>, see also L<Dist::Zilla::Plugin::GenPericmdScript>
 which lets you generate script (and its completion script) during build.
 
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>, L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Lite>,
-L<Perinci::CmdLine::Classic>
-
-L<App::GenPericmdScript>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Inline>.
@@ -1082,6 +1077,13 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>, L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Lite>,
+L<Perinci::CmdLine::Classic>
+
+L<App::GenPericmdScript>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
